@@ -4,9 +4,16 @@ from statistics import mode
 import time
 import re
 import cv2
+import imageio
 from getmac import get_mac_address as gma
+import warnings
+warnings.filterwarnings("ignore")
 
-
+ def img_estim(img, thrshld):
+                is_light = np.mean(img) > thrshld
+                return 'light' if is_light else 'dark'
+            
+            
 def inference(img_path,ocr):
     try:
         macadd=gma()
@@ -14,16 +21,29 @@ def inference(img_path,ocr):
         if macadd:
             print("Configured Sucessfully")
             image= cv2.imread(img_path)
+            f = imageio.imread(img_path, as_gray=True)
             zoom_factor=6
-            img_path= cv2.resize(image, (300,300),fx=zoom_factor, fy=zoom_factor,interpolation = cv2.INTER_NEAREST)
-            value=-55
-            hsv = cv2.cvtColor(img_path, cv2.COLOR_BGR2HSV)
-            h, s, v = cv2.split(hsv)
-            v = cv2.add(v,value)
-            v[v > 255] = 255
-            v[v < 0] = 0
-            final_hsv = cv2.merge((h, s, v))
-            img_path = cv2.cvtColor(final_hsv, cv2.COLOR_HSV2BGR)
+            val=img_estim(f,30)
+            if val=="light":
+                img_path= cv2.resize(image, (300,300),fx=zoom_factor, fy=zoom_factor,interpolation = cv2.INTER_NEAREST)
+                value=-90
+                hsv = cv2.cvtColor(img_path, cv2.COLOR_BGR2HSV)
+                h, s, v = cv2.split(hsv)
+                v = cv2.add(v,value)
+                v[v > 255] = 255
+                v[v < 0] = 0
+                final_hsv = cv2.merge((h, s, v))
+                img_path = cv2.cvtColor(final_hsv, cv2.COLOR_HSV2BGR)
+            if val=="dark":
+                img_path= cv2.resize(image, (300,300),fx=zoom_factor, fy=zoom_factor,interpolation = cv2.INTER_NEAREST)
+                value=-15
+                hsv = cv2.cvtColor(img_path, cv2.COLOR_BGR2HSV)
+                h, s, v = cv2.split(hsv)
+                v = cv2.add(v,value)
+                v[v > 255] = 255
+                v[v < 0] = 0
+                final_hsv = cv2.merge((h, s, v))
+                img_path = cv2.cvtColor(final_hsv, cv2.COLOR_HSV2BGR)
             result = ocr.ocr(img_path, cls=True)
             print(result)
             txts = [line[1][0] for line in result]
